!----------------------------------------------------------------
! Rakotomalala, C., Guizien, K., Granger, K., Lefebvre, S. Dupuy, C., Orvain, F., Modelling the functionning of a coupled Microphytobenthic-EPS_bacterial system in intertidal mudflats 
!----------------------------------------------------------------
! Function to be used with the Modular numerical tool (Eco3M) under Cecill License. The version of the code is that of 2006 
!---------------------------------------------------------------
!
        function f_resp_outC_ban(ili,jcol,tx_croiss,kn,t_opt,t_max,beta,k_C,gam_R)
!
!--------------------------------------------------------------------
!
! Cette fonction calcule la respiration du phyto lors de la synthese proteique 
!
! variables et unites:
!---------------------
! tx_croiss : taux de croissance max du phyto, s-1
! gam_R : nombre de mol de C respire par mol de N synthetise
! kn : constante de demi-saturation, mmol NID m-2
! t_opt : temperature optimale pour la croissance du phyto en C
! t_max : temperature lethale pour le phyto en C
! beta : parametre de curvature
! delta_N : ratio N/C inhibant assimilation de N
!
! Variables globales
Use COUPLEUR_PHY_BIO
Use mod_fchain

 Implicit None

!-- fonction
real(8) :: f_resp_outC_ban(nx,ny,nz)

!-- arguments
Real(8) :: tx_croiss,kn,beta,t_max,t_opt,tfunc,gam_R,k_C
Integer :: ili,jcol,id,id1

!-- variables locales:
 character(L_CHAIN)::chain1,chain2,chain3

 chain1='Dp'
 chain2 = 'N'
 chain3='NID'

id=f_scomp2id(chain1,chain2)
id1=f_scomp2id(chain3,chain2)

 tfunc= ((t_max-TEMPCp)/(t_max-t_opt))**beta*exp(-beta*((t_max-TEMPCp)/(t_max-t_opt)-1.))

  f_resp_outC_ban(:,:,:) = gam_R * &
     tx_croiss*var(id1)%conc(:,:,:)/(var(id1)%conc(:,:,:)+kn) &
    *var(ili)%conc(:,:,:)/(var(ili)%conc(:,:,:)+k_C) &
    * tfunc

!write(*,*) 'tfunc = ',tfunc
!write(*,*) 'DIN=',var(id1)%conc(:,:,:)
!write(*,*) 'var(ili)%conc(:,:,:)=',var(ili)%conc(:,:,:)
!write(*,*) 'f_resp_outC_ban = ',f_resp_outC_ban(1,1,1)

end function f_resp_outC_ban
