!----------------------------------------------------------------
! Rakotomalala, C., Guizien, K., Granger, K., Lefebvre, S. Dupuy, C., Orvain, F., Modelling the functionning of a coupled Microphytobenthic-EPS_bacterial system in intertidal mudflats 
!----------------------------------------------------------------
! Function to be used with the Modular numerical tool (Eco3M) under Cecill License. The version of the code is that of 2006 
!---------------------------------------------------------------
!
     function f_uptC_Dp_ban(ili,jcol,P_max,k_P,t_opt,t_max,beta,gamma_P)
!
!--------------------------------------------------------------------
!
! Cette fonction calcule la synthese de sucre C3 par les diatomees actives
! et la distribue dans les diatomees ou sous forme d EPS - COD
! (en fonction de l'exondation)
!
! variables et unites:
!---------------------
! P_max : taux de photosynthese max du phyto, s-1
! k_P : constante de demi-saturation pour biomasse en N pour limiter la photosynthese, mmolN m-2
! gamma_P : proportion de C stocke sous forme de sucres internes
! t_opt : temperature optimale pour la croissance du phyto en °C
! t_max : temperature lethale pour le phyto en °C
! beta : parametre de curvature
!
! Variables globales
Use COUPLEUR_PHY_BIO
Use mod_fchain

 Implicit None

!-- fonction
real(8) :: f_uptC_Dp_ban(nx,ny,nz)

!-- arguments
Real(8) :: P_max,gamma_P,k_P,beta,t_max,t_opt,KPAR,tfunc
Integer :: ili,jcol,id

!-- variables locales:
 character(L_CHAIN)::chain1,chain2

KPAR=100

 chain1='Dpact'
 chain2 = 'N'

   id=f_scomp2id(chain1,chain2)

 tfunc= ((t_max-TEMPCp)/(t_max-t_opt))**beta*exp(-beta*((t_max-TEMPCp)/(t_max-t_opt)-1.))

	f_uptC_Dp_ban(:,:,:) = gamma_P* P_max * var(id)%conc(:,:,:)/(k_P+ var(id)%conc(:,:,:))*&
       tfunc*tanh(E_PARp/KPAR)*(1.-MAREEp)

!write(*,*) 'f_uptC_Dp_ban = ',f_uptC_Dp_ban(1,1,1)
!write(*,*) 'gamma_P = ',gamma_P
!write(*,*) 'P_max = ',P_max
!write(*,*) 'Irrad = ',E_PARp
!write(*,*) 'temp = ',TEMPCp
!pause
end function f_uptC_Dp_ban
