!----------------------------------------------------------------
! Rakotomalala, C., Guizien, K., Granger, K., Lefebvre, S. Dupuy, C., Orvain, F., Modelling the functionning of a coupled Microphytobenthic-EPS_bacterial system in intertidal mudflats 
!----------------------------------------------------------------
! Function to be used with the Modular numerical tool (Eco3M) under Cecill License. The version of the code is that of 2006 
!---------------------------------------------------------------
!
     function f_uptN_Dpa_ban(ili,jcol,tx_croiss,kn,t_opt,t_max,beta,k_C)
!
!--------------------------------------------------------------------
!
! Cette fonction calcule la synthese proteique a partir du NID
! par les diatomees actives et inactives
! tx croissance dependant du stock en NID = Michaelis-Menten
! et limite le stock d energie = C dans Dp
! et variable en fonction de la temperature
!
! variables et unites:
!---------------------
! tx_croiss : taux de croissance max du phyto, s-1
! kn : constante de demi-saturation, mol NID m-3
! t_opt : temperature optimale pour la croissance du phyto en C
! t_max : temperature lethale pour le phyto en C
! beta : parametre de curvature
! delta_N : ratio N/C inhibant assimilation de N
!
! Variables globales
Use COUPLEUR_PHY_BIO
Use mod_fchain

 Implicit None

!-- fonction
real(8) :: f_uptN_Dpa_ban(nx,ny,nz)

!-- arguments
Real(8) :: tx_croiss,kn,beta,t_max,t_opt,tfunc,k_C
Integer :: ili,jcol,id

!-- variables locales:
 character(L_CHAIN)::chain1,chain2

 chain1='Dpact'
 chain2 = 'C'

id=f_scomp2id(chain1,chain2)

     tfunc= ((t_max-TEMPCp)/(t_max-t_opt))**beta*exp(-beta &
     *((t_max-TEMPCp)/(t_max-t_opt)-1.))

   f_uptN_Dpa_ban(:,:,:) =tx_croiss* &
       var(jcol)%conc(:,:,:)/(var(jcol)%conc(:,:,:)+kn)* tfunc &
       *var(id)%conc(:,:,:)/(var(id)%conc(:,:,:) + k_C )
!write(*,*) 'tx_croiss=',tx_croiss
!write(*,*) 'kn=',kn
!write(*,*) 'k_C=',k_C
!write(*,*) 'tfunc',tfunc
!write(*,*) 'f_uptN_Dpa_ban = ',f_uptN_Dpa_ban(1,1,1)
!pause
! write(*,*) 'tfunc = ',tfunc
end function f_uptN_Dpa_ban
