!----------------------------------------------------------------
! Rakotomalala, C., Guizien, K., Granger, K., Lefebvre, S. Dupuy, C., Orvain, F., Modelling the functionning of a coupled Microphytobenthic-EPS_bacterial system in intertidal mudflats 
!----------------------------------------------------------------
! Function to be used with the Modular numerical tool (Eco3M) under Cecill License. The version of the code is that of 2006 
!---------------------------------------------------------------
!
    function f_uptN_bact_ban(ili,jcol,tx_croiss,kB,kn2,t_opt,t_max,beta,beta_C)
!
!--------------------------------------------------------------------
!
! Cette fonction calcule l'absorption du NOD par les bacteries
!
! variables et unites:
!---------------------
! tx_croiss : taux de croissance max des bacteries, s-1
! kB : biomasse bact limite phase exp, en molN m-3
! kn2 : constante de demi-saturation upt NOD, en molN m-3
! t_opt : temperature optimale pour la croissance des bact en °C
! t_max : temperature lethale pour les bacteries en °C
! beta : parametre de curvature
! beta_C : parametre d inhibition par EPS:C
!
! Variables globales
Use COUPLEUR_PHY_BIO
Use mod_fchain

 Implicit None
 
!-- fonction
real(8) :: f_uptN_bact_ban(nx,ny,nz)

!-- arguments
Real(8) :: tx_croiss,kB,kn2,t_opt,t_max,beta,beta_C
Integer :: ili,jcol,id
!-- variables locales:
 character(L_CHAIN)::chain1,chain2
 
 chain1='EPS'
 chain2 = 'C'
 id=f_scomp2id(chain1,chain2)

f_uptN_bact_ban(:,:,:) =   tx_croiss * &
!       (var(ili)%conc(:,:,:)/(var(ili)%conc(:,:,:) + kB))*&
!       exp(-kB*var(ili)%conc(:,:,:))*&
       (var(jcol)%conc(:,:,:)/(var(jcol)%conc(:,:,:) + kn2))*&
     ((t_max-TEMPCp)/(t_max-t_opt))**beta*exp(-beta*((t_max-TEMPCp)/(t_max-t_opt)-1.))&
       *exp(-beta_C*var(id)%conc(:,:,:))
!write(*,*) 'f_uptN_bact_ban=',f_uptN_bact_ban(1,1,1)

! Remarque importante: vu qu'en rentrant les variables dans "config.ini",
! on commence toujours par la biomasse, le nutriment absorbe
! est toujours dans la colonne jcol du flux (ili --> jcol), et la
! biomasse est toujours dans la ligne ili
end function f_uptN_bact_ban
